@@ -1,5 +1,6 @@
 var NAVTREEINDEX1 =
 {
+"Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca29a40628cb975d91b49bc71571b64a70":[7,0,0,0,97,11],
 "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca2b01bc412ce880449f7874d1b56d31ab":[7,0,0,0,97,58],
 "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca334750b2e12a281df4cbfb49b9d8e897":[7,0,0,0,97,28],
 "Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca3573f8602d3e763afcedbc4e15c4da2d":[7,0,0,0,97,29],
@@ -82,7 +83,6 @@ var NAVTREEINDEX1 =
 "Enumerations_8H.html#af10b03e83b7216797dff35f766641056acc4328f20d0fe9f7b96aab2b60c95ff8":[7,0,0,0,98,1],
 "Enumerations_8H.html#af10b03e83b7216797dff35f766641056acd76b175e480ac306f300882d09ca4ac":[7,0,0,0,98,6],
 "Enumerations_8H.html#af10b03e83b7216797dff35f766641056aea66c96bb1b6c97e4375d7aea5fc62ff":[7,0,0,0,98,3],
-"Enumerations_8H.html#af1371824700591b5b4fa1c5469a09168":[7,0,0,0,117],
 "Enumerations_8H.html#af26a6486e65decd723fbe5c1f43deb0b":[7,0,0,0,130],
 "Enumerations_8H.html#af4708895fdb16d3982408fee68ba502b":[7,0,0,0,64],
 "Enumerations_8H.html#af50ce650b88c5fc3e3fd0ef02f99fb76":[7,0,0,0,136],
@@ -167,87 +167,87 @@ var NAVTREEINDEX1 =
 "Fl__Clock_8H_source.html":[7,0,0,21],
 "Fl__Color__Chooser_8H.html":[7,0,0,22],
 "Fl__Color__Chooser_8H_source.html":[7,0,0,22],
-"Fl__Copy__Surface_8H_source.html":[7,0,0,24],
-"Fl__Counter_8H_source.html":[7,0,0,25],
-"Fl__Device_8H.html":[7,0,0,26],
-"Fl__Device_8H_source.html":[7,0,0,26],
-"Fl__Dial_8H_source.html":[7,0,0,27],
-"Fl__Double__Window_8H_source.html":[7,0,0,28],
+"Fl__Copy__Surface_8H_source.html":[7,0,0,23],
+"Fl__Counter_8H_source.html":[7,0,0,24],
+"Fl__Device_8H.html":[7,0,0,25],
+"Fl__Device_8H_source.html":[7,0,0,25],
+"Fl__Dial_8H_source.html":[7,0,0,26],
+"Fl__Double__Window_8H_source.html":[7,0,0,27],
 "Fl__Double__Window_8cxx.html":[7,0,1,12],
-"Fl__Export_8H_source.html":[7,0,0,30],
-"Fl__File__Browser_8H_source.html":[7,0,0,31],
-"Fl__File__Chooser_8H_source.html":[7,0,0,32],
-"Fl__File__Icon_8H_source.html":[7,0,0,33],
-"Fl__File__Input_8H_source.html":[7,0,0,34],
-"Fl__Fill__Dial_8H_source.html":[7,0,0,35],
-"Fl__Fill__Slider_8H_source.html":[7,0,0,36],
-"Fl__Flex_8H_source.html":[7,0,0,37],
-"Fl__Float__Input_8H_source.html":[7,0,0,38],
-"Fl__FormsBitmap_8H_source.html":[7,0,0,39],
-"Fl__FormsPixmap_8H_source.html":[7,0,0,40],
-"Fl__Free_8H_source.html":[7,0,0,41],
-"Fl__GIF__Image_8H_source.html":[7,0,0,42],
+"Fl__Export_8H_source.html":[7,0,0,29],
+"Fl__File__Browser_8H_source.html":[7,0,0,30],
+"Fl__File__Chooser_8H_source.html":[7,0,0,31],
+"Fl__File__Icon_8H_source.html":[7,0,0,32],
+"Fl__File__Input_8H_source.html":[7,0,0,33],
+"Fl__Fill__Dial_8H_source.html":[7,0,0,34],
+"Fl__Fill__Slider_8H_source.html":[7,0,0,35],
+"Fl__Flex_8H_source.html":[7,0,0,36],
+"Fl__Float__Input_8H_source.html":[7,0,0,37],
+"Fl__FormsBitmap_8H_source.html":[7,0,0,38],
+"Fl__FormsPixmap_8H_source.html":[7,0,0,39],
+"Fl__Free_8H_source.html":[7,0,0,40],
+"Fl__GIF__Image_8H_source.html":[7,0,0,41],
 "Fl__Gl__Choice_8H_source.html":[7,0,1,14],
-"Fl__Gl__Window_8H_source.html":[7,0,0,43],
+"Fl__Gl__Window_8H_source.html":[7,0,0,42],
 "Fl__Gl__Window__Driver_8H_source.html":[7,0,1,15],
-"Fl__Graphics__Driver_8H_source.html":[7,0,0,44],
+"Fl__Graphics__Driver_8H_source.html":[7,0,0,43],
 "Fl__Graphics__Driver_8cxx.html":[7,0,1,16],
 "Fl__Graphics__Driver_8cxx.html#a679aa8deb527960e94165ff5078da591":[7,0,1,16,0],
-"Fl__Grid_8H.html":[7,0,0,45],
-"Fl__Grid_8H.html#a0afcb7a2332d538db21bdf0e8f51eba4":[7,0,0,45,9],
-"Fl__Grid_8H.html#a0c6403e2a2a7dac8d5cce25e54be3a9f":[7,0,0,45,2],
-"Fl__Grid_8H.html#a4dd6fe62c153174a2799ebb6c081580b":[7,0,0,45,11],
-"Fl__Grid_8H.html#a7378bed2c1683c31ab9d7161204ab84b":[7,0,0,45,6],
-"Fl__Grid_8H.html#a78c6c930732fcc7251fefc0c21577a96":[7,0,0,45,4],
-"Fl__Grid_8H.html#a9e117f657f6541794e6993fe18fa73da":[7,0,0,45,8],
-"Fl__Grid_8H.html#aa9c2f3604ad45506ffa757e65d28914b":[7,0,0,45,5],
-"Fl__Grid_8H.html#ad79b49c462a7332b87af0443da5fc0a7":[7,0,0,45,10],
-"Fl__Grid_8H.html#ad9f5e4176b158c5ab879bc30a6aa0161":[7,0,0,45,7],
-"Fl__Grid_8H.html#ae990197d9181698ba9000ecb817da848":[7,0,0,45,3],
-"Fl__Grid_8H_source.html":[7,0,0,45],
+"Fl__Grid_8H.html":[7,0,0,44],
+"Fl__Grid_8H.html#a0afcb7a2332d538db21bdf0e8f51eba4":[7,0,0,44,9],
+"Fl__Grid_8H.html#a0c6403e2a2a7dac8d5cce25e54be3a9f":[7,0,0,44,2],
+"Fl__Grid_8H.html#a4dd6fe62c153174a2799ebb6c081580b":[7,0,0,44,11],
+"Fl__Grid_8H.html#a7378bed2c1683c31ab9d7161204ab84b":[7,0,0,44,6],
+"Fl__Grid_8H.html#a78c6c930732fcc7251fefc0c21577a96":[7,0,0,44,4],
+"Fl__Grid_8H.html#a9e117f657f6541794e6993fe18fa73da":[7,0,0,44,8],
+"Fl__Grid_8H.html#aa9c2f3604ad45506ffa757e65d28914b":[7,0,0,44,5],
+"Fl__Grid_8H.html#ad79b49c462a7332b87af0443da5fc0a7":[7,0,0,44,10],
+"Fl__Grid_8H.html#ad9f5e4176b158c5ab879bc30a6aa0161":[7,0,0,44,7],
+"Fl__Grid_8H.html#ae990197d9181698ba9000ecb817da848":[7,0,0,44,3],
+"Fl__Grid_8H_source.html":[7,0,0,44],
 "Fl__Grid_8cxx.html":[7,0,1,17],
-"Fl__Group_8H.html":[7,0,0,46],
-"Fl__Group_8H_source.html":[7,0,0,46],
-"Fl__Help__Dialog_8H_source.html":[7,0,0,47],
-"Fl__Help__View_8H_source.html":[7,0,0,48],
-"Fl__Hold__Browser_8H_source.html":[7,0,0,49],
-"Fl__Hor__Fill__Slider_8H_source.html":[7,0,0,50],
-"Fl__Hor__Nice__Slider_8H_source.html":[7,0,0,51],
-"Fl__Hor__Slider_8H_source.html":[7,0,0,52],
-"Fl__Hor__Value__Slider_8H_source.html":[7,0,0,53],
-"Fl__ICO__Image_8H_source.html":[7,0,0,54],
-"Fl__Image_8H.html":[7,0,0,55],
-"Fl__Image_8H.html#a79b21b0aede6293a7521b40ff6196368":[7,0,0,55,2],
-"Fl__Image_8H.html#a79b21b0aede6293a7521b40ff6196368ab3d220f85e1cde2e88ce74512e7a80af":[7,0,0,55,2,0],
-"Fl__Image_8H.html#a79b21b0aede6293a7521b40ff6196368ad4908fc3630eabed1601e67e18bcd179":[7,0,0,55,2,1],
-"Fl__Image_8H_source.html":[7,0,0,55],
+"Fl__Group_8H.html":[7,0,0,45],
+"Fl__Group_8H_source.html":[7,0,0,45],
+"Fl__Help__Dialog_8H_source.html":[7,0,0,46],
+"Fl__Help__View_8H_source.html":[7,0,0,47],
+"Fl__Hold__Browser_8H_source.html":[7,0,0,48],
+"Fl__Hor__Fill__Slider_8H_source.html":[7,0,0,49],
+"Fl__Hor__Nice__Slider_8H_source.html":[7,0,0,50],
+"Fl__Hor__Slider_8H_source.html":[7,0,0,51],
+"Fl__Hor__Value__Slider_8H_source.html":[7,0,0,52],
+"Fl__ICO__Image_8H_source.html":[7,0,0,53],
+"Fl__Image_8H.html":[7,0,0,54],
+"Fl__Image_8H.html#a79b21b0aede6293a7521b40ff6196368":[7,0,0,54,2],
+"Fl__Image_8H.html#a79b21b0aede6293a7521b40ff6196368ab3d220f85e1cde2e88ce74512e7a80af":[7,0,0,54,2,0],
+"Fl__Image_8H.html#a79b21b0aede6293a7521b40ff6196368ad4908fc3630eabed1601e67e18bcd179":[7,0,0,54,2,1],
+"Fl__Image_8H_source.html":[7,0,0,54],
 "Fl__Image__Reader_8h_source.html":[7,0,1,18],
-"Fl__Image__Surface_8H_source.html":[7,0,0,56],
-"Fl__Input_8H_source.html":[7,0,0,57],
-"Fl__Input__Choice_8H_source.html":[7,0,0,59],
-"Fl__Input___8H_source.html":[7,0,0,58],
-"Fl__Int__Input_8H_source.html":[7,0,0,60],
+"Fl__Image__Surface_8H_source.html":[7,0,0,55],
+"Fl__Input_8H_source.html":[7,0,0,56],
+"Fl__Input__Choice_8H_source.html":[7,0,0,58],
+"Fl__Input___8H_source.html":[7,0,0,57],
+"Fl__Int__Input_8H_source.html":[7,0,0,59],
 "Fl__Int__Vector_8H_source.html":[7,0,1,19],
-"Fl__JPEG__Image_8H_source.html":[7,0,0,61],
-"Fl__Light__Button_8H_source.html":[7,0,0,62],
-"Fl__Line__Dial_8H_source.html":[7,0,0,63],
-"Fl__Menu_8H_source.html":[7,0,0,64],
-"Fl__Menu__Bar_8H_source.html":[7,0,0,66],
-"Fl__Menu__Button_8H_source.html":[7,0,0,67],
-"Fl__Menu__Item_8H.html":[7,0,0,68],
-"Fl__Menu__Item_8H_source.html":[7,0,0,68],
-"Fl__Menu__Window_8H_source.html":[7,0,0,69],
-"Fl__Menu___8H_source.html":[7,0,0,65],
+"Fl__JPEG__Image_8H_source.html":[7,0,0,60],
+"Fl__Light__Button_8H_source.html":[7,0,0,61],
+"Fl__Line__Dial_8H_source.html":[7,0,0,62],
+"Fl__Menu_8H_source.html":[7,0,0,63],
+"Fl__Menu__Bar_8H_source.html":[7,0,0,65],
+"Fl__Menu__Button_8H_source.html":[7,0,0,66],
+"Fl__Menu__Item_8H.html":[7,0,0,67],
+"Fl__Menu__Item_8H_source.html":[7,0,0,67],
+"Fl__Menu__Window_8H_source.html":[7,0,0,68],
+"Fl__Menu___8H_source.html":[7,0,0,64],
 "Fl__Message_8h_source.html":[7,0,1,20],
-"Fl__Multi__Browser_8H_source.html":[7,0,0,71],
-"Fl__Multi__Label_8H_source.html":[7,0,0,72],
-"Fl__Multiline__Input_8H_source.html":[7,0,0,73],
-"Fl__Multiline__Output_8H_source.html":[7,0,0,74],
-"Fl__Native__File__Chooser_8H.html":[7,0,0,75],
-"Fl__Native__File__Chooser_8H_source.html":[7,0,0,75],
+"Fl__Multi__Browser_8H_source.html":[7,0,0,70],
+"Fl__Multi__Label_8H_source.html":[7,0,0,71],
+"Fl__Multiline__Input_8H_source.html":[7,0,0,72],
+"Fl__Multiline__Output_8H_source.html":[7,0,0,73],
+"Fl__Native__File__Chooser_8H.html":[7,0,0,74],
+"Fl__Native__File__Chooser_8H_source.html":[7,0,0,74],
 "Fl__Native__File__Chooser__Kdialog_8H_source.html":[7,0,1,21],
 "Fl__Native__File__Chooser__Zenity_8H_source.html":[7,0,1,22],
-"Fl__Nice__Slider_8H_source.html":[7,0,0,76],
-"Fl__Object_8H_source.html":[7,0,0,77],
-"Fl__Output_8H_source.html":[7,0,0,78]
+"Fl__Nice__Slider_8H_source.html":[7,0,0,75],
+"Fl__Object_8H_source.html":[7,0,0,76],
+"Fl__Output_8H_source.html":[7,0,0,77]
 };
