@@ -1,5 +1,9 @@
 var NAVTREEINDEX14 =
 {
+"classFl__Window.html#a615bf5d04b79df5c8f53f3dcdf19e9b5":[6,0,153,1],
+"classFl__Window.html#a62d20d4914c1e18e054653bc34f1209c":[6,0,153,55],
+"classFl__Window.html#a65a2499309b3fdd1bed463cefa0cd1e2":[6,0,153,50],
+"classFl__Window.html#a6b96d2dad3e3a4dd186e3ce7a1f14387":[6,0,153,53],
 "classFl__Window.html#a72f5733f13cb6d8b646f1e7ffcd92333":[6,0,153,8],
 "classFl__Window.html#a747b5a42083e70bf0768627e8dfb0ebf":[6,0,153,67],
 "classFl__Window.html#a75b94c3386351a44a0ef97b8e435eecb":[6,0,153,2],
@@ -245,9 +249,5 @@ var NAVTREEINDEX14 =
 "examples.html#examples_pixmap_browser":[0,20,0,55],
 "examples.html#examples_preferences":[0,20,0,56],
 "examples.html#examples_radio":[0,20,0,57],
-"examples.html#examples_resize":[0,20,0,60],
-"examples.html#examples_resizebox":[0,20,0,58],
-"examples.html#examples_rotated_text":[0,20,0,59],
-"examples.html#examples_scroll":[0,20,0,61],
-"examples.html#examples_shape":[0,20,0,62]
+"examples.html#examples_resize":[0,20,0,60]
 };
