@@ -1,5 +1,8 @@
 var NAVTREEINDEX16 =
 {
+"globals_func.html":[7,1,1],
+"globals_func.html":[7,1,1,0],
+"globals_func_b.html":[7,1,1,1],
 "globals_func_c.html":[7,1,1,2],
 "globals_func_d.html":[7,1,1,3],
 "globals_func_e.html":[7,1,1,4],
@@ -41,7 +44,7 @@ var NAVTREEINDEX16 =
 "globals_x.html":[7,1,0,23],
 "globals_y.html":[7,1,0,24],
 "globals_z.html":[7,1,0,25],
-"glu_8h_source.html":[7,0,0,154],
+"glu_8h_source.html":[7,0,0,153],
 "glut.html":[0,15],
 "glut.html#glut_Fl_Glut_Window":[0,15,3],
 "glut.html#glut_class_hierarchy":[0,15,3,0],
@@ -52,7 +55,7 @@ var NAVTREEINDEX16 =
 "glut.html#glut_methods":[0,15,3,4],
 "glut.html#glut_mixing":[0,15,2],
 "glut.html#glut_using":[0,15,0],
-"glut_8H_source.html":[7,0,0,155],
+"glut_8H_source.html":[7,0,0,154],
 "group__callback__functions.html":[5,0],
 "group__callback__functions.html#ga0cd86d9a18073304779213e82747ac8a":[5,0,14],
 "group__callback__functions.html#ga17b5c6570394124287997166a50ff07a":[5,0,15],
@@ -200,6 +203,7 @@ var NAVTREEINDEX16 =
 "group__fl__drawings.html#ga5b8f9bd2d3130529812dcc2c057eee35":[5,6,36],
 "group__fl__drawings.html#ga5f8de0bccbd6b3e7dbe6542d1b092b69":[5,6,52],
 "group__fl__drawings.html#ga60522372d52422ab427d540d375a43ad":[5,6,98],
+"group__fl__drawings.html#ga63a4cd645de3dd10145568367beebba7":[5,6,40],
 "group__fl__drawings.html#ga63a94b99c2a0290f170c25f735297ad2":[5,6,95],
 "group__fl__drawings.html#ga63b2b306812f12741f271b469e192a8e":[5,6,10],
 "group__fl__drawings.html#ga66c104e927de31864a58af60d0a3e92a":[5,6,26],
@@ -227,7 +231,6 @@ var NAVTREEINDEX16 =
 "group__fl__drawings.html#gaaf5f078d4c685a9b643518e811c201cf":[5,6,32],
 "group__fl__drawings.html#gab002201c2d4dfd87f82c3bd039d92ecc":[5,6,75],
 "group__fl__drawings.html#gab09bbd653e95e654562966e2f3956ffd":[5,6,80],
-"group__fl__drawings.html#gab0ebac3ea2825182d49cfce0ad51b681":[5,6,40],
 "group__fl__drawings.html#gab12cb4aaa22092a0f2ae3d349c57f234":[5,6,18],
 "group__fl__drawings.html#gab14ee2f4c5371ab6fe52bf08569e05d9":[5,6,73],
 "group__fl__drawings.html#gab2a13525800bed49c0154562d523717f":[5,6,93],
@@ -246,8 +249,5 @@ var NAVTREEINDEX16 =
 "group__fl__drawings.html#gacf46b232b6439424cc7f53656c5c2226":[5,6,111],
 "group__fl__drawings.html#gad032c5f7637d440ff545285f2dcc2f44":[5,6,48],
 "group__fl__drawings.html#gad0933d77b61a0c93dee0c636962d094b":[5,6,94],
-"group__fl__drawings.html#gad71ca0866541afbf5f87eb90f483a12e":[5,6,103],
-"group__fl__drawings.html#gad752f20cc18c2618b5130272764e0f0d":[5,6,30],
-"group__fl__drawings.html#gad94ad795f70c2ef011ff458783c2c018":[5,6,85],
-"group__fl__drawings.html#gada306dd9c67eea142a0b3c752520b04c":[5,6,13]
+"group__fl__drawings.html#gad71ca0866541afbf5f87eb90f483a12e":[5,6,103]
 };
