@@ -1,5 +1,8 @@
 var NAVTREEINDEX18 =
 {
+"iso8859__5_8h_source.html":[7,0,1,0,1,22],
+"iso8859__6_8h_source.html":[7,0,1,0,1,23],
+"iso8859__7_8h_source.html":[7,0,1,0,1,24],
 "iso8859__8_8h_source.html":[7,0,1,0,1,25],
 "iso8859__9_8h_source.html":[7,0,1,0,1,26],
 "iso8859__9e_8h_source.html":[7,0,1,0,1,27],
@@ -11,9 +14,9 @@ var NAVTREEINDEX18 =
 "koi8__u_8h_source.html":[7,0,1,0,1,33],
 "ksc5601_8h_source.html":[7,0,1,0,1,34],
 "license.html":[0,19],
-"mac_8H.html":[7,0,0,156],
-"mac_8H_source.html":[7,0,0,156],
-"math_8h_source.html":[7,0,0,157],
+"mac_8H.html":[7,0,0,155],
+"mac_8H_source.html":[7,0,0,155],
+"math_8h_source.html":[7,0,0,156],
 "mediumarrow_8h_source.html":[7,0,1,38],
 "migration_1_4.html":[0,18],
 "migration_1_4.html#migration_1_4_copy_image":[0,18,4],
@@ -26,8 +29,8 @@ var NAVTREEINDEX18 =
 "migration_1_4.html#migration_1_4_x11_compat":[0,18,5],
 "mk__wcwidth_8c_source.html":[7,0,1,0,3],
 "mulelao_8h_source.html":[7,0,1,0,1,35],
-"names_8h.html":[7,0,0,158],
-"names_8h_source.html":[7,0,0,158],
+"names_8h.html":[7,0,0,157],
+"names_8h_source.html":[7,0,0,157],
 "numericsort_8c.html":[7,0,1,39],
 "numericsort_8c.html#a0b2d01d871793cb319e486f89a6d1c3e":[7,0,1,39,0],
 "numericsort_8c.html#a8a624f01e44b5462d6eca0567fb9c641":[7,0,1,39,1],
@@ -77,18 +80,18 @@ var NAVTREEINDEX18 =
 "osissues.html#osissues_xresources":[0,17,2,5],
 "osissues.html#osissues_xvisual":[0,17,2,2],
 "pages.html":[],
-"platform_8H_source.html":[7,0,0,159],
-"platform__types_8h.html":[7,0,0,160],
-"platform__types_8h.html#a25fe41b1bd340d52f7970051d8b680bc":[7,0,0,160,1],
-"platform__types_8h.html#a5c7c4e4558d665307552718e828d28d8":[7,0,0,160,3],
-"platform__types_8h.html#a5d4011c75b1fe25d9ef36e8ae9e2995c":[7,0,0,160,0],
-"platform__types_8h.html#aa488d0a3bed15e82539fcf42384eb153":[7,0,0,160,8],
-"platform__types_8h.html#abe7c95701dd7f8d2a112aff7e0ff5345":[7,0,0,160,6],
-"platform__types_8h.html#ac8e78a1cbd640e700961c06785b83409":[7,0,0,160,7],
-"platform__types_8h.html#adb631ddcd69e049ecd3ce0df56624bbb":[7,0,0,160,4],
-"platform__types_8h.html#af2b4daf25dc744e8cea191ee827ce767":[7,0,0,160,5],
-"platform__types_8h.html#afea081b5e7799663f2634b3bfba67409":[7,0,0,160,2],
-"platform__types_8h_source.html":[7,0,0,160],
+"platform_8H_source.html":[7,0,0,158],
+"platform__types_8h.html":[7,0,0,159],
+"platform__types_8h.html#a25fe41b1bd340d52f7970051d8b680bc":[7,0,0,159,1],
+"platform__types_8h.html#a5c7c4e4558d665307552718e828d28d8":[7,0,0,159,3],
+"platform__types_8h.html#a5d4011c75b1fe25d9ef36e8ae9e2995c":[7,0,0,159,0],
+"platform__types_8h.html#aa488d0a3bed15e82539fcf42384eb153":[7,0,0,159,8],
+"platform__types_8h.html#abe7c95701dd7f8d2a112aff7e0ff5345":[7,0,0,159,6],
+"platform__types_8h.html#ac8e78a1cbd640e700961c06785b83409":[7,0,0,159,7],
+"platform__types_8h.html#adb631ddcd69e049ecd3ce0df56624bbb":[7,0,0,159,4],
+"platform__types_8h.html#af2b4daf25dc744e8cea191ee827ce767":[7,0,0,159,5],
+"platform__types_8h.html#afea081b5e7799663f2634b3bfba67409":[7,0,0,159,2],
+"platform__types_8h_source.html":[7,0,0,159],
 "preface.html":[0,0],
 "preface.html#preface_abbreviations":[0,0,2],
 "preface.html#preface_conventions":[0,0,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX18 =
 "structFl__Paged__Device_1_1page__format.html#ab281b2d2443be0bb9f7fbe59c87346bd":[6,0,90,0,1],
 "structFl__Preferences_1_1Entry.html":[6,0,99,0],
 "structFl__Scroll_1_1Fl__Region__LRTB.html":[6,0,114,0],
-"structFl__Scroll_1_1Fl__Region__LRTB.html#a30c172f8d46c0dd3ef984f8bf3f4bfae":[6,0,114,0,2],
-"structFl__Scroll_1_1Fl__Region__LRTB.html#a4b025c0301af8bad486e00db5c808f16":[6,0,114,0,0],
-"structFl__Scroll_1_1Fl__Region__LRTB.html#a639c8c025b30d5bec5b19880eb747724":[6,0,114,0,1],
-"structFl__Scroll_1_1Fl__Region__LRTB.html#a74f844879de21902233eca3c2d244d01":[6,0,114,0,3]
+"structFl__Scroll_1_1Fl__Region__LRTB.html#a30c172f8d46c0dd3ef984f8bf3f4bfae":[6,0,114,0,2]
 };
